@@ -1,4 +1,5 @@
 import pandas as pd
+from tqdm import tqdm
 import glob
 
 
@@ -6,7 +7,7 @@ def csv2h5(directory=None, files=None):
 
     if directory == None:
 
-        for file in files:
+        for file in tqdm(files):
 
             df = pd.read_csv(file)
 
@@ -22,7 +23,7 @@ def csv2h5(directory=None, files=None):
 
         files = glob.glob(csv_files_dir)
 
-        for file in files:
+        for file in tqdm(files):
 
             df = pd.read_csv(file)
 
